deeplake.auto.unstructured.image_classification
===============================================
.. currentmodule:: deeplake.auto.unstructured.image_classification
.. autoclass:: ImageClassification
    :members: